#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_ROL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_ROL_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/rol.hpp>

#endif
